@@ -216,6 +216,7 @@ static void slider_index_sum_core_impl(const double* p_x,
     sum_state_finalize,
     sum_nodes_increment,
     sum_nodes_initialize,
+    sum_nodes_void_deref,
     na_rm ? sum_na_rm_aggregate_from_leaves : sum_na_keep_aggregate_from_leaves,
     na_rm ? sum_na_rm_aggregate_from_nodes : sum_na_keep_aggregate_from_nodes
   );
@@ -300,6 +301,7 @@ static void slider_index_prod_core_impl(const double* p_x,
     prod_state_finalize,
     prod_nodes_increment,
     prod_nodes_initialize,
+    prod_nodes_void_deref,
     na_rm ? prod_na_rm_aggregate_from_leaves : prod_na_keep_aggregate_from_leaves,
     na_rm ? prod_na_rm_aggregate_from_nodes : prod_na_keep_aggregate_from_nodes
   );
@@ -384,6 +386,7 @@ static void slider_index_mean_core_impl(const double* p_x,
     mean_state_finalize,
     mean_nodes_increment,
     mean_nodes_initialize,
+    mean_nodes_void_deref,
     na_rm ? mean_na_rm_aggregate_from_leaves : mean_na_keep_aggregate_from_leaves,
     na_rm ? mean_na_rm_aggregate_from_nodes : mean_na_keep_aggregate_from_nodes
   );
@@ -468,6 +471,7 @@ static void slider_index_min_core_impl(const double* p_x,
     min_state_finalize,
     min_nodes_increment,
     min_nodes_initialize,
+    min_nodes_void_deref,
     na_rm ? min_na_rm_aggregate_from_leaves : min_na_keep_aggregate_from_leaves,
     na_rm ? min_na_rm_aggregate_from_nodes : min_na_keep_aggregate_from_nodes
   );
@@ -552,6 +556,7 @@ static void slider_index_max_core_impl(const double* p_x,
     max_state_finalize,
     max_nodes_increment,
     max_nodes_initialize,
+    max_nodes_void_deref,
     na_rm ? max_na_rm_aggregate_from_leaves : max_na_keep_aggregate_from_leaves,
     na_rm ? max_na_rm_aggregate_from_nodes : max_na_keep_aggregate_from_nodes
   );
@@ -636,6 +641,7 @@ static void slider_index_all_core_impl(const int* p_x,
     all_state_finalize,
     all_nodes_increment,
     all_nodes_initialize,
+    all_nodes_void_deref,
     na_rm ? all_na_rm_aggregate_from_leaves : all_na_keep_aggregate_from_leaves,
     na_rm ? all_na_rm_aggregate_from_nodes : all_na_keep_aggregate_from_nodes
   );
@@ -720,6 +726,7 @@ static void slider_index_any_core_impl(const int* p_x,
     any_state_finalize,
     any_nodes_increment,
     any_nodes_initialize,
+    any_nodes_void_deref,
     na_rm ? any_na_rm_aggregate_from_leaves : any_na_keep_aggregate_from_leaves,
     na_rm ? any_na_rm_aggregate_from_nodes : any_na_keep_aggregate_from_nodes
   );
